@@ -13,11 +13,12 @@ import java.util.Vector;
 
 import org.gnu.glib.EventMap;
 import org.gnu.glib.EventType;
+import org.gnu.glib.GObject;
+import org.gnu.glib.Handle;
 import org.gnu.glib.Type;
 import org.gnu.gnome.event.IconEntryEvent;
 import org.gnu.gnome.event.IconEntryListener;
 import org.gnu.gtk.VBox;
-import org.gnu.glib.Handle;
 
 /**
  * A GnomeIconEntry is a button that pops up a window displaying a collection of
@@ -27,6 +28,21 @@ import org.gnu.glib.Handle;
  */
 public class IconEntry extends VBox {
 
+    /**
+     * Internal static factory method to be used by Java-Gnome only.
+     */
+    public static IconEntry getIconEntry(Handle handle) {
+        if (handle == null) {
+            return null;
+        }
+
+        IconEntry iconEntry = (IconEntry) GObject.getGObjectFromHandle(handle);
+        if (iconEntry == null) {
+            iconEntry = new IconEntry(handle);
+        }
+        return iconEntry;
+    }
+
     private Vector listeners;
 
     /**
